summaryrefslogtreecommitdiff
path: root/src/setup/mainmenu.c
diff options
context:
space:
mode:
authorSimon Howard2009-11-21 16:36:46 +0000
committerSimon Howard2009-11-21 16:36:46 +0000
commitafa0c4c7979c1508605d0e79487f299cd03adda6 (patch)
tree7df1745badf169e4490e3a56a89a28ac37977c14 /src/setup/mainmenu.c
parent095bc1110b3c11fbf2e17bfd51bf78909fe34662 (diff)
parent2c6e7b2f10c32ca0406ca6753e7701d83e6dea8f (diff)
downloadchocolate-doom-afa0c4c7979c1508605d0e79487f299cd03adda6.tar.gz
chocolate-doom-afa0c4c7979c1508605d0e79487f299cd03adda6.tar.bz2
chocolate-doom-afa0c4c7979c1508605d0e79487f299cd03adda6.zip
Merge from trunk.
Subversion-branch: /branches/raven-branch Subversion-revision: 1737
Diffstat (limited to 'src/setup/mainmenu.c')
-rw-r--r--src/setup/mainmenu.c9
1 files changed, 7 insertions, 2 deletions
diff --git a/src/setup/mainmenu.c b/src/setup/mainmenu.c
index 3b79bc94..46e4b4e6 100644
--- a/src/setup/mainmenu.c
+++ b/src/setup/mainmenu.c
@@ -19,6 +19,7 @@
// 02111-1307, USA.
//
+#include <stdio.h>
#include <stdlib.h>
#include <string.h>
@@ -175,6 +176,10 @@ void MainMenu(void)
TXT_SetWindowAction(window, TXT_HORIZ_LEFT, quit_action);
}
+//
+// Initialize all configuration variables, load config file, etc
+//
+
static void InitConfig(void)
{
InitBindings();
@@ -228,7 +233,7 @@ static void SetIcon(void)
}
//
// Initialise and run the textscreen GUI.
//
static void RunGUI(void)
@@ -237,7 +242,7 @@ static void RunGUI(void)
if (!TXT_Init())
{
- fprintf(stderr, "Failed to initialise GUI\n");
+ fprintf(stderr, "Failed to initialize GUI\n");
exit(-1);
}
@@ -228,7 +233,7 @@ static void SetIcon(void)
}
//
-// Initialise and run the textscreen GUI.
+// Initialize and run the textscreen GUI.
//
static void RunGUI(void)